Class: Object
- Inherits:
- BasicObject
- Defined in:
- lib/pyper/default_includes.rb
Instance Method Summary collapse
-
#π ⇒ Object
Method π is defined on Object, that enables Pyper method calls.
Method π is defined on Object, that enables Pyper method calls.